@@ -5,33 +5,25 @@ class TrafficRateLimit:
     KB = 1024
     MEGABIT = KB * 125
 
-    def __init__(self, capacity, rate=None):
+    def __init__(self, capacity, rate):
         """
         令牌桶法按照带宽限速限速
         capacity: 带宽
         rate: 速率 capacity/second
         """
         self.capacity = float(capacity)
-        if not rate:
-            self.rate = self.capacity
-        else:
-            self.rate = rate
+        self.rate = rate
 
         self._remain_traffic = self.capacity
         self._last_time = time()
-        self._cur_rate = 0
 
     def consume(self, traffic_lens):
-        time_delta = time() - self._last_time
-        self.fill(time_delta)
-
+        self.fill()
         # NOTE _remain_traffic 可以为负数
         self._remain_traffic -= traffic_lens
-        self._cur_rate = traffic_lens / time_delta
 
-    def fill(self, time_delta=None):
-        if not time_delta:
-            time_delta = time() - self._last_time
+    def fill(self):
+        time_delta = time() - self._last_time
         self._last_time += time_delta
 
         if self._remain_traffic < 0:
@@ -56,22 +48,3 @@ class TrafficRateLimit:
             return False
         self.fill()
         return self._remain_traffic < 0
-
-    def get_sleep_time(self):
-        if self._remain_traffic > 0:
-            return 0
-        else:
-            return abs(self._remain_traffic) / self.rate
-
-
-class TcpConnRateLimit:
-    def __init__(self, capacity):
-        self.capacity = capacity
-        self.tcp_conn_num = 0
-
-    def incr_tcp_conn_num(self, num):
-        self.tcp_conn_num += num
-
-    @property
-    def limited(self):
-        return self.tcp_conn_num > self.capacity
