@@ -43,20 +43,22 @@ def parse_header(data):
 
 class AutoResetBloomFilter:
 
-    MAX_ELEMENTS = 10 ** 6
+    MAX_ELEMENTS = 10 ** 5
     ERROR_RATE = 10 ** -6
 
-    def new_bf(self):
-        self.size = self.MAX_ELEMENTS
-        return BloomFilter(max_elements=self.MAX_ELEMENTS, error_rate=self.ERROR_RATE)
+    @classmethod
+    def new_bf(cls):
+        return BloomFilter(max_elements=cls.MAX_ELEMENTS, error_rate=cls.ERROR_RATE)
 
     def __init__(self):
         self.bf = self.new_bf()
+        self.size = self.MAX_ELEMENTS
 
     def add(self, v):
         if self.size <= 0:
             logging.warning("bloom filter reset")
             self.bf = self.new_bf()
+            self.size = self.MAX_ELEMENTS
         self.bf.add(v)
         self.size -= 1
 
